==> jc-1.4.0.tar.gz: gnu/java/net/protocol/ftp/ActiveModeDTP.h <==
// final class gnu.java.net.protocol.ftp.ActiveModeDTP

// class file dependencies
// @dep_class 2e30d543088f39ef gnu_java_net_protocol_ftp_ActiveModeDTP
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_ftp_ActiveModeDTP_H_
#define _JC_gnu_java_net_protocol_ftp_ActiveModeDTP_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object;
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object;
struct _jc_java_io_IOException$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Thread$object;
struct _jc_java_net_InetAddress$object;
struct _jc_java_net_ServerSocket$object;
struct _jc_java_net_Socket$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_refs	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$refs	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$nonrefs	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vmethods	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtable	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtype	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$_init$62180a0e90621789(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *, struct _jc_java_net_InetAddress$object *, jint, jint, jint);

// Virtual methods
extern jboolean _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$abort$e796432fcfca78e8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *);
extern void _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$complete$51c4339c04062948(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *);
extern struct _jc_java_io_InputStream$object *_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *);
extern struct _jc_java_io_OutputStream$object *_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$getOutputStream$1f50a8d1fe1542e3(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *);
extern void _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *);
extern void _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$setTransferMode$02f0de2cb653dfc0(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *, jint);
extern void _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$transferComplete$ae2c162c293821ce(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *);
extern void _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$waitFor$deb7fe4016880d4c(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$abort$e796432fcfca78e8;
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$complete$51c4339c04062948;
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$getOutputStream$1f50a8d1fe1542e3;
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$setTransferMode$02f0de2cb653dfc0;
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$transferComplete$ae2c162c293821ce;
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$waitFor$deb7fe4016880d4c;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vmethods {
	jboolean	(*abort$e796432fcfca78e8)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *);
	void	(*complete$51c4339c04062948)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *);
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *);
	struct _jc_java_io_OutputStream$object	*(*getOutputStream$1f50a8d1fe1542e3)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *);
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *);
	void	(*setTransferMode$02f0de2cb653dfc0)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *, jint);
	void	(*transferComplete$ae2c162c293821ce)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *);
	void	(*waitFor$deb7fe4016880d4c)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vmethods	gnu_java_net_protocol_ftp_ActiveModeDTP;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_refs {
	struct _jc_java_net_ServerSocket$object	*server;
	struct _jc_java_net_Socket$object	*socket;
	struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object	*in;
	struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object	*out;
	struct _jc_java_io_IOException$object	*exception;
	struct _jc_java_lang_Thread$object	*acceptThread;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$refs {
    _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_refs	gnu_java_net_protocol_ftp_ActiveModeDTP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_nonrefs {
	jboolean	completed;
	jboolean	inProgress;
	jint	transferMode;
	jint	connectionTimeout;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_nonrefs	gnu_java_net_protocol_ftp_ActiveModeDTP;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object {
	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtype _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_ActiveModeDTP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_ActiveModeDTP_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/ftp/ActiveModeDTP.h <==
// final class gnu.java.net.protocol.ftp.ActiveModeDTP

// class file dependencies
// @dep_class 2e30d543088f39ef gnu_java_net_protocol_ftp_ActiveModeDTP
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_ftp_ActiveModeDTP_H_
#define _JC_gnu_java_net_protocol_ftp_ActiveModeDTP_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object;
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object;
struct _jc_java_io_IOException$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Thread$object;
struct _jc_java_net_InetAddress$object;
struct _jc_java_net_ServerSocket$object;
struct _jc_java_net_Socket$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_refs	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$refs	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$nonrefs	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vmethods	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtable	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtype	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$_init$62180a0e90621789(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *, struct _jc_java_net_InetAddress$object *, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$abort$e796432fcfca78e8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$complete$51c4339c04062948(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_InputStream$object *_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_OutputStream$object *_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$getOutputStream$1f50a8d1fe1542e3(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$setTransferMode$02f0de2cb653dfc0(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$transferComplete$ae2c162c293821ce(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method$waitFor$deb7fe4016880d4c(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$abort$e796432fcfca78e8;
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$complete$51c4339c04062948;
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$getOutputStream$1f50a8d1fe1542e3;
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$setTransferMode$02f0de2cb653dfc0;
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$transferComplete$ae2c162c293821ce;
extern _jc_method _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$method_info$waitFor$deb7fe4016880d4c;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vmethods {
	jboolean	(*abort$e796432fcfca78e8)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *) _JC_JCNI_ATTR;
	void	(*complete$51c4339c04062948)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_OutputStream$object	*(*getOutputStream$1f50a8d1fe1542e3)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *) _JC_JCNI_ATTR;
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *) _JC_JCNI_ATTR;
	void	(*setTransferMode$02f0de2cb653dfc0)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *, jint) _JC_JCNI_ATTR;
	void	(*transferComplete$ae2c162c293821ce)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *) _JC_JCNI_ATTR;
	void	(*waitFor$deb7fe4016880d4c)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vmethods	gnu_java_net_protocol_ftp_ActiveModeDTP;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_refs {
	struct _jc_java_net_ServerSocket$object	*server;
	struct _jc_java_net_Socket$object	*socket;
	struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object	*in;
	struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object	*out;
	struct _jc_java_io_IOException$object	*exception;
	struct _jc_java_lang_Thread$object	*acceptThread;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$refs {
    _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_refs	gnu_java_net_protocol_ftp_ActiveModeDTP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_nonrefs {
	jboolean	completed;
	jboolean	inProgress;
	jint	transferMode;
	jint	connectionTimeout;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$sub_nonrefs	gnu_java_net_protocol_ftp_ActiveModeDTP;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$object {
	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_ActiveModeDTP$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$vtype _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_ActiveModeDTP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_ActiveModeDTP$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_ActiveModeDTP_H_ */
